@@ -464,8 +464,9 @@ shuffle.spike.times <- function (s, noise.sd) {
 }
 
 
-fourplot <- function(s, names=FALSE) {
+fourplot <- function(s, names=FALSE, raster.time=NULL) {
   ## Simple 2x2 summary plot of an "s" structure.
+  ## raster.time should be a 2-vector of (beg, end) time.
   old.par <- par(no.readonly = TRUE)
   on.exit(par(old.par))
   
@@ -473,7 +474,13 @@ fourplot <- function(s, names=FALSE) {
   
   plot(s$layout, use.names=names)                        #show layout of electrodes.
   plot.meanfiringrate(s, main='')
-  plot(s, main='', label.cells=names, use.names=names)                      #plot the spikes.
+  if (is.null(raster.time)) {
+    plot(s, main='', label.cells=names, use.names=names)                      #plot the spikes.
+  }
+  else {
+    plot(s, main='', label.cells=names, use.names=names,
+         beg=raster.time[1], end=raster.time[2])
+  }
 
   ##   if	(!is.na(s$corr$corr.indexes[1])) {
   if( any(names(s)=="corr")) {
